==> haskell-hiedb-0.4.1.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hiedb
version:              0.4.1.0
visibility:           public
id:                   hiedb-0.4.1.0-GDtBZ3QUWRJ2RFfhfKK2cS
key:                  hiedb-0.4.1.0-GDtBZ3QUWRJ2RFfhfKK2cS
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  c8f99517f1cc138b4c8041db6bd7d9be
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hiedb-0.4.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hiedb-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hiedb-0.4.1.0
hs-libraries:         HShiedb-0.4.1.0-GDtBZ3QUWRJ2RFfhfKK2cS
depends:
    algebraic-graphs-0.5-3KgrLA7zNA06Fxg8v3WZOW
    ansi-terminal-0.11-DjCjwOSLGFf1dS0V09gtOz array-0.5.4.0
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 extra-1.7.10-BjGZFAYpXsjDqImjYsZuGK
    filepath-1.4.2.1 ghc-9.0.1
    hie-compat-0.2.0.0-HHVbuGAk8zeLJ4sWoPjDO6
    lucid-2.9.12.1-7mKqu190CmP1mKRQtViCil mtl-2.2.2
    optparse-applicative-0.16.1.0-2Lys88r8Sg3GstjsK1qq7I
    sqlite-simple-0.4.18.0-IxgoHRkXfnz79Nh6oN4yGI
    terminal-size-0.3.2.1-8rLUbNor4uN6iQgtxjW6lw text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hiedb-0.4.1.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hiedb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hiedb
version:              0.4.1.0
visibility:           public
id:                   hiedb-0.4.1.0-FJiSZYjMGCI45BiUxlBkV3
key:                  hiedb-0.4.1.0-FJiSZYjMGCI45BiUxlBkV3
license:              BSD-3-Clause
copyright:            Zubin Duggal
maintainer:           zubin.duggal@gmail.com
author:               Zubin Duggal
synopsis:             Generates a references DB from .hie files
description:
    Tool and library to index and query a collection of `.hie` files

category:             Development
abi:                  3ade48c572a62693f8ed0feaf8b37429
exposed:              True
exposed-modules:
    HieDb HieDb.Compat HieDb.Create HieDb.Dump HieDb.Html HieDb.Query
    HieDb.Run HieDb.Types HieDb.Utils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hiedb-0.4.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hiedb-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hiedb-0.4.1.0
hs-libraries:         HShiedb-0.4.1.0-FJiSZYjMGCI45BiUxlBkV3
depends:
    algebraic-graphs-0.5-Em1lV5viphAuJ07GovE3M
    ansi-terminal-0.11-Kvq5JBN7BE16HA1JfrRBzw array-0.5.4.0
    base-4.15.0.0 bytestring-0.10.12.1 containers-0.6.4.1
    directory-1.3.6.1 extra-1.7.10-32H3SA4Yf8dI1sU3NgBQjm
    filepath-1.4.2.1 ghc-9.0.1
    hie-compat-0.2.0.0-HHVbuGAk8zeLJ4sWoPjDO6
    lucid-2.9.12.1-ElUJ01wTTH05DhClcgeKdU mtl-2.2.2
    optparse-applicative-0.16.1.0-2gAu0ltAuRsE34mFhrRUQs
    sqlite-simple-0.4.18.0-4q9dkrZpIsQ9fsS09MgnXH
    terminal-size-0.3.2.1-8rLUbNor4uN6iQgtxjW6lw text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-hiedb/html/hiedb.haddock
haddock-html:         /usr/share/doc/haskell-hiedb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
